@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@ from hyperkitty.search_indexes import update_index
 
 class Job(BaseJob):
     help = "Update the full-text index"
-    when = "minutely"
+    when = "hourly"
 
     def execute(self):
         run_with_lock(update_index, remove=False)
